@@ -66,7 +66,12 @@
 
 			// Expand term node
 			_displayTermSubnodes: function(term, nodes) {
-				var source = $("A:econtains(" + term.replace('&#039;','\'') + ")").siblings('IMG.plminus');
+				var source = $.data($.ZTFY.thesaurus.tree, 'source');
+				if (source) {
+					source = source[term];
+				} else {
+					source = $("A:econtains(" + term.replace('&#039;','\'') + ")").siblings('IMG.plminus');
+				}
 				var source_div = $(source).closest('DIV').get(0);
 				var tree = $(source).closest('DIV.tree');
 				var show_links = tree.data('ztfy-tree-details') != 'off';
@@ -145,6 +150,7 @@
 			_expandCallback: function(result, status) {
 				if (status == 'success') {
 					$.ZTFY.thesaurus.tree._displayTermSubnodes(result.term, result.nodes);
+					$.removeData($.ZTFY.thesaurus.tree, 'source');
 				}
 			},
 
